==> haskell-typst-0.5.0.2-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-typst.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 typst
version:              0.5.0.2
visibility:           public
id:                   typst-0.5.0.2-A3yyZNwV9Qy7bviilwPHUK
key:                  typst-0.5.0.2-A3yyZNwV9Qy7bviilwPHUK
license:              BSD-3-Clause
copyright:            Copyright 2023 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Parsing and evaluating typst syntax.
description:
    A library for parsing and evaluating typst syntax.
    Typst (<https://typst.app>) is a document layout and
    formatting language. This library targets typst 0.10
    and currently offers only partial support.

category:             Text
abi:                  486fcc5dd4ffc3e0ff9c46674b18976c
exposed:              True
exposed-modules:
    Typst Typst.Evaluate Typst.Methods Typst.Parse Typst.Syntax
    Typst.Types Typst.Util

hidden-modules:
    Typst.Bind Typst.Regex Typst.Show Typst.Module.Standard
    Typst.Module.Math Typst.Module.Calc Typst.MathClass

import-dirs:          /usr/lib/ghc-9.4.8/site-local/typst-0.5.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/typst-0.5.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/typst-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-typst
hs-libraries:         HStypst-0.5.0.2-A3yyZNwV9Qy7bviilwPHUK
depends:
    aeson-2.1.2.1-LDBL5bcX1HC79scYyh3opi array-0.5.4.0 base-4.17.2.1
    bytestring-0.11.5.3 cassava-0.5.3.2-HB0L9fb5BO3DwATcwa64JO
    containers-0.6.7 directory-1.3.7.1 filepath-1.4.2.2 mtl-2.2.2
    ordered-containers-0.2.4-3fE9A9fYh485SXz5Vw3oUC parsec-3.1.16.1
    pretty-1.1.3.6 regex-tdfa-1.3.2.4-4spaPYpacr92ooLlQb3epN
    scientific-0.3.7.0-EYP4lwU6ELFEdSU4sCeddu text-2.0.2 time-1.12.2
    toml-parser-2.0.1.0-8SnuUgn7xSY7yQIppvcS9U
    typst-symbols-0.1.5-CKv9nghfbzV9YElGsqLgYY
    vector-0.13.1.0-Dc65CzydytHE52tdajtbOv
    xml-conduit-1.9.1.4-5DeSVAXqJ1xJGgslyd8Cwp
    yaml-0.11.11.2-7NEgW6E2pbYEs4sf4NTDIA

haddock-interfaces:   /usr/share/doc/haskell-typst/html/typst.haddock
haddock-html:         /usr/share/doc/haskell-typst/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-typst-0.5.0.2-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-typst.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 typst
version:              0.5.0.2
visibility:           public
id:                   typst-0.5.0.2-FrO8rJw4fO0HQbPLXbbRVW
key:                  typst-0.5.0.2-FrO8rJw4fO0HQbPLXbbRVW
license:              BSD-3-Clause
copyright:            Copyright 2023 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Parsing and evaluating typst syntax.
description:
    A library for parsing and evaluating typst syntax.
    Typst (<https://typst.app>) is a document layout and
    formatting language. This library targets typst 0.10
    and currently offers only partial support.

category:             Text
abi:                  4666ce0e59a85b724900af94c974a373
exposed:              True
exposed-modules:
    Typst Typst.Evaluate Typst.Methods Typst.Parse Typst.Syntax
    Typst.Types Typst.Util

hidden-modules:
    Typst.Bind Typst.Regex Typst.Show Typst.Module.Standard
    Typst.Module.Math Typst.Module.Calc Typst.MathClass

import-dirs:          /usr/lib/ghc-9.4.8/site-local/typst-0.5.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/typst-0.5.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/typst-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-typst
hs-libraries:         HStypst-0.5.0.2-FrO8rJw4fO0HQbPLXbbRVW
depends:
    aeson-2.1.2.1-17AWhWkbfJE926UMi0wPlA array-0.5.4.0 base-4.17.2.1
    bytestring-0.11.5.3 cassava-0.5.3.2-7XnNZcnrz2n67s2m22Qf5o
    containers-0.6.7 directory-1.3.7.1 filepath-1.4.2.2 mtl-2.2.2
    ordered-containers-0.2.4-3fE9A9fYh485SXz5Vw3oUC parsec-3.1.16.1
    pretty-1.1.3.6 regex-tdfa-1.3.2.4-4spaPYpacr92ooLlQb3epN
    scientific-0.3.7.0-LbVWmnmXBYJ1OlsceRex9A text-2.0.2 time-1.12.2
    toml-parser-2.0.1.0-7fBxJBWpfSxIcEDyQpZHGY
    typst-symbols-0.1.5-CKv9nghfbzV9YElGsqLgYY
    vector-0.13.1.0-Dc65CzydytHE52tdajtbOv
    xml-conduit-1.9.1.4-1XbN0ypGG1ZKTuVRFIjLWV
    yaml-0.11.11.2-80c9kV5MpRFFIswGhdKXlt

haddock-interfaces:   /usr/share/doc/haskell-typst/html/typst.haddock
haddock-html:         /usr/share/doc/haskell-typst/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
